==> node-nodemailer_6.7.1+~6.4.4.orig.tar.gz: nodemailer-6.7.1/test/sendmail/le-unix.test.js <==
/* eslint no-unused-expressions:0, prefer-arrow-callback: 0 */
/* globals describe, it */

'use strict';

const LeUnix = require('../../lib/mime-node/le-unix');
const chai = require('chai');
const expect = chai.expect;

chai.config.includeStack = true;

describe('Sendmail Unix Newlines', function () {
    it('should rewrite all linebreaks (byte by byte)', function (done) {
        let source = 'tere tere\nteine rida\nkolmas rida\r\nneljas rida\r\nviies rida\n kuues rida';

        let chunks = [];
        let out = new LeUnix();
        out.on('data', chunk => chunks.push(chunk));
        out.on('end', () => {
            expect(Buffer.concat(chunks).toString()).to.equal(source.replace(/\r?\n/g, '\n'));
            done();
        });

        let data = Buffer.from(source);
        let pos = 0;
        let writeNextByte = () => {
            if (pos >= data.length) {
                return out.end();
            }
            out.write(Buffer.from([data[pos++]]));
            setImmediate(writeNextByte);
        };

        setImmediate(writeNextByte);
    });

    it('should rewrite all linebreaks (all at once)', function (done) {
        let source = 'tere tere\nteine rida\nkolmas rida\r\nneljas rida\r\nviies rida\n kuues rida';

        let chunks = [];
        let out = new LeUnix();
        out.on('data', chunk => chunks.push(chunk));
        out.on('end', () => {
            expect(Buffer.concat(chunks).toString()).to.equal(source.replace(/\r?\n/g, '\n'));
            done();
        });

        let data = Buffer.from(source);
        out.end(data);
    });
});

==> node-nodemailer_6.10.0+~6.4.17.orig.tar.gz: nodemailer-6.10.0/test/sendmail/le-unix.test.js <==
'use strict';

const { describe, it } = require('node:test');
const assert = require('node:assert/strict');
const LeUnix = require('../../lib/mime-node/le-unix');

describe('Sendmail Unix Newlines', () => {
    it('should rewrite all linebreaks (byte by byte)', (t, done) => {
        let source = 'tere tere\nteine rida\nkolmas rida\r\nneljas rida\r\nviies rida\n kuues rida';

        let chunks = [];
        let out = new LeUnix();
        out.on('data', chunk => chunks.push(chunk));
        out.on('end', () => {
            assert.strictEqual(Buffer.concat(chunks).toString(), source.replace(/\r?\n/g, '\n'));
            done();
        });

        let data = Buffer.from(source);
        let pos = 0;
        let writeNextByte = () => {
            if (pos >= data.length) {
                return out.end();
            }
            out.write(Buffer.from([data[pos++]]));
            setImmediate(writeNextByte);
        };

        setImmediate(writeNextByte);
    });

    it('should rewrite all linebreaks (all at once)', (t, done) => {
        let source = 'tere tere\nteine rida\nkolmas rida\r\nneljas rida\r\nviies rida\n kuues rida';

        let chunks = [];
        let out = new LeUnix();
        out.on('data', chunk => chunks.push(chunk));
        out.on('end', () => {
            assert.strictEqual(Buffer.concat(chunks).toString(), source.replace(/\r?\n/g, '\n'));
            done();
        });

        let data = Buffer.from(source);
        out.end(data);
    });
});
